==> customer-link-project-api-1.0.11-20231114.094237-7-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/appisv1/vo/PrizeVO.java <==

package cn.com.duiba.customer.link.project.api.remoteservice.appisv1.vo;



/**
 * 获得的奖品
 * 
 */
public class PrizeVO {

    /**
     * 奖项图
     * (Required)
     * 
     */
    private String optionImg;
    /**
     * 发奖记录id
     * (Required)
     * 
     */
    private Long userRecordId;
    /**
     * 奖品类型（1-道具，2-兑吧奖品）
     * (Required)
     * 
     */
    private Integer prizeType;
    /**
     * 奖项id
     * (Required)
     * 
     */
    private String optionId;
    /**
     * 奖项名
     * (Required)
     * 
     */
    private String optionName;
    /**
     * 奖品id
     * (Required)
     * 
     */
    private String prizeId;
    /**
     * 发奖详情链接
     * (Required)
     * 
     */
    private String url;

    /**
     * 单次发放个数
     */
    private Long sendCount;

    /**
     * 奖项图
     * (Required)
     * 
     */
    public String getOptionImg() {
        return optionImg;
    }

    /**
     * 奖项图
     * (Required)
     * 
     */
    public void setOptionImg(String optionImg) {
        this.optionImg = optionImg;
    }

    /**
     * 发奖记录id
     * (Required)
     * 
     */
    public Long getUserRecordId() {
        return userRecordId;
    }

    /**
     * 发奖记录id
     * (Required)
     * 
     */
    public void setUserRecordId(Long userRecordId) {
        this.userRecordId = userRecordId;
    }

    /**
     * 奖品类型（1-道具，2-兑吧奖品）
     * (Required)
     * 
     */
    public Integer getPrizeType() {
        return prizeType;
    }

    /**
     * 奖品类型（1-道具，2-兑吧奖品）
     * (Required)
     * 
     */
    public void setPrizeType(Integer prizeType) {
        this.prizeType = prizeType;
    }

    /**
     * 奖项id
     * (Required)
     * 
     */
    public String getOptionId() {
        return optionId;
    }

    /**
     * 奖项id
     * (Required)
     * 
     */
    public void setOptionId(String optionId) {
        this.optionId = optionId;
    }

    /**
     * 奖项名
     * (Required)
     * 
     */
    public String getOptionName() {
        return optionName;
    }

    /**
     * 奖项名
     * (Required)
     * 
     */
    public void setOptionName(String optionName) {
        this.optionName = optionName;
    }

    /**
     * 奖品id
     * (Required)
     * 
     */
    public String getPrizeId() {
        return prizeId;
    }

    /**
     * 奖品id
     * (Required)
     * 
     */
    public void setPrizeId(String prizeId) {
        this.prizeId = prizeId;
    }

    /**
     * 发奖详情链接
     * (Required)
     * 
     */
    public String getUrl() {
        return url;
    }

    /**
     * 发奖详情链接
     * (Required)
     * 
     */
    public void setUrl(String url) {
        this.url = url;
    }

    public Long getSendCount() {
        return sendCount;
    }

    public void setSendCount(Long sendCount) {
        this.sendCount = sendCount;
    }
}

==> customer-link-project-api-1.1.46-20250921.044633-5-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/appisv1/vo/PrizeVO.java <==

package cn.com.duiba.customer.link.project.api.remoteservice.appisv1.vo;



/**
 * 获得的奖品
 * 
 */
public class PrizeVO {

    /**
     * 发奖规则
     */
    private String ruId;

    /**
     * 奖项图
     * (Required)
     * 
     */
    private String optionImg;
    /**
     * 发奖记录id
     * (Required)
     * 
     */
    private Long userRecordId;
    /**
     * 奖品类型（1-道具，2-兑吧奖品）
     * (Required)
     * 
     */
    private Integer prizeType;
    /**
     * 奖项id
     * (Required)
     * 
     */
    private String optionId;
    /**
     * 奖项名
     * (Required)
     * 
     */
    private String optionName;
    /**
     * 奖品id
     * (Required)
     * 
     */
    private String prizeId;
    /**
     * 发奖详情链接
     * (Required)
     * 
     */
    private String url;

    /**
     * 单次发放个数
     */
    private Long sendCount;

    /**
     * 扩展字段
     */
    private String extra;

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    /**
     * 奖项图
     * (Required)
     * 
     */
    public String getOptionImg() {
        return optionImg;
    }

    /**
     * 奖项图
     * (Required)
     * 
     */
    public void setOptionImg(String optionImg) {
        this.optionImg = optionImg;
    }

    /**
     * 发奖记录id
     * (Required)
     * 
     */
    public Long getUserRecordId() {
        return userRecordId;
    }

    /**
     * 发奖记录id
     * (Required)
     * 
     */
    public void setUserRecordId(Long userRecordId) {
        this.userRecordId = userRecordId;
    }

    /**
     * 奖品类型（1-道具，2-兑吧奖品）
     * (Required)
     * 
     */
    public Integer getPrizeType() {
        return prizeType;
    }

    /**
     * 奖品类型（1-道具，2-兑吧奖品）
     * (Required)
     * 
     */
    public void setPrizeType(Integer prizeType) {
        this.prizeType = prizeType;
    }

    /**
     * 奖项id
     * (Required)
     * 
     */
    public String getOptionId() {
        return optionId;
    }

    /**
     * 奖项id
     * (Required)
     * 
     */
    public void setOptionId(String optionId) {
        this.optionId = optionId;
    }

    /**
     * 奖项名
     * (Required)
     * 
     */
    public String getOptionName() {
        return optionName;
    }

    /**
     * 奖项名
     * (Required)
     * 
     */
    public void setOptionName(String optionName) {
        this.optionName = optionName;
    }

    /**
     * 奖品id
     * (Required)
     * 
     */
    public String getPrizeId() {
        return prizeId;
    }

    /**
     * 奖品id
     * (Required)
     * 
     */
    public void setPrizeId(String prizeId) {
        this.prizeId = prizeId;
    }

    /**
     * 发奖详情链接
     * (Required)
     * 
     */
    public String getUrl() {
        return url;
    }

    /**
     * 发奖详情链接
     * (Required)
     * 
     */
    public void setUrl(String url) {
        this.url = url;
    }

    public Long getSendCount() {
        return sendCount;
    }

    public void setSendCount(Long sendCount) {
        this.sendCount = sendCount;
    }

    public String getRuId() {
        return ruId;
    }

    public void setRuId(String ruId) {
        this.ruId = ruId;
    }
}
